rm(list=ls(all=TRUE)) # clear workspace

library(sjPlot)
library(mediation)
library(ggplot2)
library(nnet)
library(countrycode)
library(diagram)

# bring in data
core <- read.csv("KoppReederWright_replication_data.csv")

# add country name (for plot creation)
core$country <- countrycode(core$cow, "cown", "country.name")

# main models, using mid involvement index
# models
fit.totaleffect <- lm(escAdes~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorIV <- lm(repression~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorDV <- lm(escAdes~repression+I(repression^2)+I(repression^3)+index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
# print out results
tab_model(fit.totaleffect, fit.mediatorIV, fit.mediatorDV, digits=3, show.ci=F, vcov.args=list(cluster=core$cow))
# plot main effect (repression)
plot_model(fit.mediatorDV, terms=c("repression"), type="eff") + labs(title="", x="Change in Repression", y="Change in Internal Conflict Intensity")
# use mediation package for summary
results <- mediation::mediate(fit.mediatorIV, fit.mediatorDV, treat='index', mediator='repression', boot=T, long=F, cluster=core$cow)
summary(results)
plot(results, treatment="both")

# Disaggregated Analysis (on each component of Index)
# proportion
fit.totaleffect.prop <- lm(escAdes~prop+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorIV.prop <- lm(repression~prop+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorDV.prop <- lm(escAdes~repression+I(repression^2)+I(repression^3)+prop+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
# frequency
fit.totaleffect.freq <- lm(escAdes~freq+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorIV.freq <- lm(repression~freq+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorDV.freq <- lm(escAdes~repression+I(repression^2)+I(repression^3)+freq+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
# hostility level
fit.totaleffect.host <- lm(escAdes~host+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorIV.host <- lm(repression~host+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
fit.mediatorDV.host <- lm(escAdes~repression+I(repression^2)+I(repression^3)+host+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)

# model specifications 
# time fixed effects 
fit.totaleffect.tfe <- lm(escAdes~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(year), data=core)
fit.mediatorIV.tfe <- lm(repression~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(year), data=core)
fit.mediatorDV.tfe <- lm(escAdes~repression+I(repression^2)+I(repression^3)+index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(year), data=core)
# country fixed effects 
fit.totaleffect.cfe <- lm(escAdes~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow), data=core)
fit.mediatorIV.cfe <- lm(repression~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow), data=core)
fit.mediatorDV.cfe <- lm(escAdes~repression+I(repression^2)+I(repression^3)+index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow), data=core)
# time and country fixed effects 
fit.totaleffect.ctfe <- lm(escAdes~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow)+factor(year), data=core)
fit.mediatorIV.ctfe <- lm(repression~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow)+factor(year), data=core)
fit.mediatorDV.ctfe <- lm(escAdes~repression+I(repression^2)+I(repression^3)+index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt+factor(cow)+factor(year), data=core)
# multinomial logit
# interaction model
fit.mediatorDV.int <- lm(escAdes~repression*index+I(repression^2)*index+I(repression^3)*index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core)
# only civil conflict history countries 
fit.totaleffect.hist <- lm(escAdes~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core[core$cyrs > 0,])
fit.mediatorIV.hist <- lm(repression~index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core[core$cyrs > 0,])
fit.mediatorDV.hist <- lm(escAdes~repression+I(repression^2)+I(repression^3)+index+rep5yr+cc5yr+dem+gdpLN+popLN+ef+perLN+expLN+rt, data=core[core$cyrs > 0,])

# triangle mediation results figure 
data <- c(0, "'0.028**'", 0,
          0, 0, 0, 
          "'.326**(1); 0.017(2); -0.036**(3)'", "'0.013'", 0)
M<- matrix (nrow=3, ncol=3, byrow = TRUE, data=data)
plotmat(M, pos=c(1,2), 
           name= c( "Change in Repression","International Conflict Involvement", "Civil Conflict Escalation"), 
           box.type = "rect", box.size = 0.12, box.prop=0.5,  curve=0, shadow.size=0)

# facet plot for all cases
ggplot(data=core, aes(x=year)) + 
  geom_line(aes(y=index), color="steelblue") +
  geom_point(aes(y=index), color="steelblue", size=0.5) +
  geom_line(aes(y=repression), color="darkred") +
  geom_point(aes(y=repression), color="darkred", size=0.5) +
  labs(x="", y="") + 
  facet_wrap(~country)

